==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkAVSucdReader.java <==
// java wrapper for vtkAVSucdReader object
//

package vtk;
import vtk.*;

public class vtkAVSucdReader extends vtkUnstructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetBinaryFile_4(int id0);
  public void SetBinaryFile(int id0)
    { SetBinaryFile_4(id0); }

  private native int GetBinaryFile_5();
  public int GetBinaryFile()
    { return GetBinaryFile_5(); }

  private native void BinaryFileOn_6();
  public void BinaryFileOn()
    { BinaryFileOn_6(); }

  private native void BinaryFileOff_7();
  public void BinaryFileOff()
    { BinaryFileOff_7(); }

  private native int GetNumberOfCells_8();
  public int GetNumberOfCells()
    { return GetNumberOfCells_8(); }

  private native int GetNumberOfNodes_9();
  public int GetNumberOfNodes()
    { return GetNumberOfNodes_9(); }

  private native int GetNumberOfNodeFields_10();
  public int GetNumberOfNodeFields()
    { return GetNumberOfNodeFields_10(); }

  private native int GetNumberOfCellFields_11();
  public int GetNumberOfCellFields()
    { return GetNumberOfCellFields_11(); }

  private native int GetNumberOfFields_12();
  public int GetNumberOfFields()
    { return GetNumberOfFields_12(); }

  private native int GetNumberOfNodeComponents_13();
  public int GetNumberOfNodeComponents()
    { return GetNumberOfNodeComponents_13(); }

  private native int GetNumberOfCellComponents_14();
  public int GetNumberOfCellComponents()
    { return GetNumberOfCellComponents_14(); }

  private native void SetByteOrderToBigEndian_15();
  public void SetByteOrderToBigEndian()
    { SetByteOrderToBigEndian_15(); }

  private native void SetByteOrderToLittleEndian_16();
  public void SetByteOrderToLittleEndian()
    { SetByteOrderToLittleEndian_16(); }

  private native String GetByteOrderAsString_17();
  public String GetByteOrderAsString()
    { return GetByteOrderAsString_17(); }

  private native void SetByteOrder_18(int id0);
  public void SetByteOrder(int id0)
    { SetByteOrder_18(id0); }

  private native int GetByteOrder_19();
  public int GetByteOrder()
    { return GetByteOrder_19(); }

  private native int GetNumberOfPointArrays_20();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_20(); }

  private native int GetNumberOfCellArrays_21();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_21(); }

  private native String GetPointArrayName_22(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_22(id0); }

  private native String GetCellArrayName_23(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_23(id0); }

  private native int GetPointArrayStatus_24(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_24(id0); }

  private native int GetCellArrayStatus_25(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_25(id0); }

  private native void SetPointArrayStatus_26(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_26(id0,id1); }

  private native void SetCellArrayStatus_27(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_27(id0,id1); }

  private native void DisableAllCellArrays_28();
  public void DisableAllCellArrays()
    { DisableAllCellArrays_28(); }

  private native void EnableAllCellArrays_29();
  public void EnableAllCellArrays()
    { EnableAllCellArrays_29(); }

  private native void DisableAllPointArrays_30();
  public void DisableAllPointArrays()
    { DisableAllPointArrays_30(); }

  private native void EnableAllPointArrays_31();
  public void EnableAllPointArrays()
    { EnableAllPointArrays_31(); }

  public vtkAVSucdReader() { super(); }

  public vtkAVSucdReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkAVSucdReader.java <==
// java wrapper for vtkAVSucdReader object
//

package vtk;
import vtk.*;

public class vtkAVSucdReader extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetBinaryFile_4(int id0);
  public void SetBinaryFile(int id0)
    { SetBinaryFile_4(id0); }

  private native int GetBinaryFile_5();
  public int GetBinaryFile()
    { return GetBinaryFile_5(); }

  private native void BinaryFileOn_6();
  public void BinaryFileOn()
    { BinaryFileOn_6(); }

  private native void BinaryFileOff_7();
  public void BinaryFileOff()
    { BinaryFileOff_7(); }

  private native int GetNumberOfCells_8();
  public int GetNumberOfCells()
    { return GetNumberOfCells_8(); }

  private native int GetNumberOfNodes_9();
  public int GetNumberOfNodes()
    { return GetNumberOfNodes_9(); }

  private native int GetNumberOfNodeFields_10();
  public int GetNumberOfNodeFields()
    { return GetNumberOfNodeFields_10(); }

  private native int GetNumberOfCellFields_11();
  public int GetNumberOfCellFields()
    { return GetNumberOfCellFields_11(); }

  private native int GetNumberOfFields_12();
  public int GetNumberOfFields()
    { return GetNumberOfFields_12(); }

  private native int GetNumberOfNodeComponents_13();
  public int GetNumberOfNodeComponents()
    { return GetNumberOfNodeComponents_13(); }

  private native int GetNumberOfCellComponents_14();
  public int GetNumberOfCellComponents()
    { return GetNumberOfCellComponents_14(); }

  private native void SetByteOrderToBigEndian_15();
  public void SetByteOrderToBigEndian()
    { SetByteOrderToBigEndian_15(); }

  private native void SetByteOrderToLittleEndian_16();
  public void SetByteOrderToLittleEndian()
    { SetByteOrderToLittleEndian_16(); }

  private native String GetByteOrderAsString_17();
  public String GetByteOrderAsString()
    { return GetByteOrderAsString_17(); }

  private native void SetByteOrder_18(int id0);
  public void SetByteOrder(int id0)
    { SetByteOrder_18(id0); }

  private native int GetByteOrder_19();
  public int GetByteOrder()
    { return GetByteOrder_19(); }

  private native int GetNumberOfPointArrays_20();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_20(); }

  private native int GetNumberOfCellArrays_21();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_21(); }

  private native String GetPointArrayName_22(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_22(id0); }

  private native String GetCellArrayName_23(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_23(id0); }

  private native int GetPointArrayStatus_24(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_24(id0); }

  private native int GetCellArrayStatus_25(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_25(id0); }

  private native void SetPointArrayStatus_26(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_26(id0,id1); }

  private native void SetCellArrayStatus_27(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_27(id0,id1); }

  private native void DisableAllCellArrays_28();
  public void DisableAllCellArrays()
    { DisableAllCellArrays_28(); }

  private native void EnableAllCellArrays_29();
  public void EnableAllCellArrays()
    { EnableAllCellArrays_29(); }

  private native void DisableAllPointArrays_30();
  public void DisableAllPointArrays()
    { DisableAllPointArrays_30(); }

  private native void EnableAllPointArrays_31();
  public void EnableAllPointArrays()
    { EnableAllPointArrays_31(); }

  public vtkAVSucdReader() { super(); }

  public vtkAVSucdReader(long id) { super(id); }
  public native long   VTKInit();

}
